==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/CellKeyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PrimaryKeyValueDescriptionMetadata } from "./PrimaryKeyValueDescriptionMetadata";
import { CellKeyDescription } from "./CellKeyDescription";
/**
 * @hidden
 */
var CellKeyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CellKeyDescriptionMetadata, _super);
    function CellKeyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CellKeyDescriptionMetadata.b = function (a) {
        if (CellKeyDescriptionMetadata.a == null) {
            CellKeyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CellKeyDescriptionMetadata.c(CellKeyDescriptionMetadata.a);
        }
        if (a.g(CellKeyDescriptionMetadata.a)) {
            return;
        }
        a.s(CellKeyDescriptionMetadata.a);
        PrimaryKeyValueDescriptionMetadata.d(a);
    };
    CellKeyDescriptionMetadata.c = function (a) {
        a.item("PrimaryKey", "ExportedType:PrimaryKeyValue");
        a.item("RowItem", "Unknown");
        a.item("ColumnUniqueKey", "String");
    };
    CellKeyDescriptionMetadata.d = function (a) {
        CellKeyDescriptionMetadata.b(a);
        a.u("CellKey", function () { return new CellKeyDescription(); });
        a.t("CellKey", CellKeyDescriptionMetadata.a);
    };
    CellKeyDescriptionMetadata.$t = markType(CellKeyDescriptionMetadata, 'CellKeyDescriptionMetadata');
    CellKeyDescriptionMetadata.a = null;
    return CellKeyDescriptionMetadata;
}(Base));
export { CellKeyDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CellKeyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PrimaryKeyValueDescriptionMetadata } from "./PrimaryKeyValueDescriptionMetadata";
import { CellKeyDescription } from "./CellKeyDescription";
/**
 * @hidden
 */
var CellKeyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CellKeyDescriptionMetadata, _super);
    function CellKeyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CellKeyDescriptionMetadata.b = function (a) {
        if (CellKeyDescriptionMetadata.a == null) {
            CellKeyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CellKeyDescriptionMetadata.c(CellKeyDescriptionMetadata.a);
        }
        if (a.j(CellKeyDescriptionMetadata.a)) {
            return;
        }
        a.y(CellKeyDescriptionMetadata.a);
        PrimaryKeyValueDescriptionMetadata.d(a);
    };
    CellKeyDescriptionMetadata.c = function (a) {
        a.item("PrimaryKey", "ExportedType:PrimaryKeyValue");
        a.item("RowItem", "Unknown");
        a.item("ColumnUniqueKey", "String");
    };
    CellKeyDescriptionMetadata.d = function (a) {
        CellKeyDescriptionMetadata.b(a);
        a.aa("CellKey", function () { return new CellKeyDescription(); });
        a.z("CellKey", CellKeyDescriptionMetadata.a);
    };
    CellKeyDescriptionMetadata.$t = markType(CellKeyDescriptionMetadata, 'CellKeyDescriptionMetadata');
    CellKeyDescriptionMetadata.a = null;
    return CellKeyDescriptionMetadata;
}(Base));
export { CellKeyDescriptionMetadata };
